/*
 * Copyright 2018 ETH Zuerich, CISD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.ethz.sis.filetransfer;

/**
 * @author pkupczyk
 */
public class DefaultSerializerProvider implements ISerializerProvider
{

    private ILogger logger;

    private IDownloadItemIdSerializer itemIdSerializer;

    public DefaultSerializerProvider(ILogger logger)
    {
        this(new IDownloadItemIdSerializer()
            {
                @Override
                public byte[] serialize(IDownloadItemId itemId) throws DownloadException
                {
                    return itemId.getId().getBytes();
                }
            }, logger);
    }

    public DefaultSerializerProvider(IDownloadItemIdSerializer itemIdSerializer, ILogger logger)
    {
        this.logger = logger;
        this.itemIdSerializer = itemIdSerializer;
    }

    @Override
    public IChunkSerializer createChunkSerializer()
    {
        return new DefaultChunkSerializer(logger, itemIdSerializer);
    }

}
